/*
 * Project_name:
     Port Expander port on LED
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Second release;
    - 20101026(RR);
 * Description:
     This is code that shows on LEDs what are input values on Port Expander Module Ports.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf

     Dev.Board:       Easy8051v6
                      http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/

     Oscillator:      External Clock 8.0000 MHz

     Ext. Modules:    Port Expander Board
                      http://www.mikroe.com/eng/products/view/142/port-expander-board/

     SW:              mikroC PRO for 8051 v2.20
                      http://www.mikroe.com/en/compilers/mikroc/8051/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
                                                 Selector on 0 (all three jumpers A0, A1 and A2)
  - Turn On LED Switches for Port0 and Port2 (SW7.1 and SW7.3)
*/


// Port Expander module connections
sbit  SPExpanderRST at P1_0_bit;
sbit  SPExpanderCS  at P1_1_bit;
// End Port Expander module connections

void main(){

  P0 = 0;
  P2 = 0;

  Spi1_Init();
  Expander_Init(0);                           // initialize port expander

  Expander_Set_DirectionPortA(0, 0xFF);       // set expander's portA to be input
  Expander_Set_PullUpsPortA(0, 0xFF);         // set expander's portA pull-up resistors

  Expander_Set_DirectionPortB(0, 0xFF);       // set expander's portB to be input
  Expander_Set_PullUpsPortB(0, 0xFF);         // set expander's portB pull-up resistors

  while(1) {
    P0 = Expander_Read_PortA(0);              // display expander's portA on portB leds
    P2 = Expander_Read_PortB(0);              // display expander's portB on portD leds
    Delay_100ms();
  }
}
