/*
 * Project_name:
     Port Expander port on RS232
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Initial release;
    - 20101029(RR);
 * Description:
     This is code that shows over RS232 what are input values on Port Expander Module Ports.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf

     Dev.Board:       Easy8051v6
                      http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/

     Oscillator:      External Clock 8.0000 MHz

     Ext. Modules:    Port Expander Board
                      http://www.mikroe.com/eng/products/view/142/port-expander-board/
       
     SW:              mikroC PRO for 8051 v2.20
                      http://www.mikroe.com/en/compilers/mikroc/8051/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
                                                 Selector on 0 (all three jumpers A0, A1 and A2)
  - Turn On RS232 Switches (SW8.5 and SW8.6)
*/


// Port Expander module connections
sbit  SPExpanderRST at P1_0_bit;
sbit  SPExpanderCS  at P1_1_bit;
// End Port Expander module connections

char byteread;

void Byte2Bin_UART(char data1) {
  char mask;

  mask = 0b10000000;
  while (mask > 0 ) {
    if (data1 & mask)
      UART1_Write(49);
    else
      UART1_Write(48);
    mask >>= 1;
  }
  UART1_Write(13);
  UART1_Write(10);
}

void main(){                            // Main Program
  UART1_Init(4800);

  Spi1_Init();
  Expander_Init(0);                     // initialize port expander

  Expander_Set_DirectionPortA(0, 0xFF); // set expander's portA to be input
  Expander_Set_PullUpsPortA(0, 0xFF);   // set expander's portA pull-up resistors

  Expander_Set_DirectionPortB(0, 0xFF); // set expander's portB to be input
  Expander_Set_PullUpsPortB(0, 0xFF);   // set expander's portB pull-up resistors

  while(1) {
    byteread = Expander_Read_PortA(0);
    UART1_Write('A');
    UART1_Write(':');
    Byte2Bin_UART(byteread);

    byteread = Expander_Read_PortB(0);
    UART1_Write('B');
    UART1_Write(':');
    Byte2Bin_UART(byteread);

    UART1_Write(13);
    UART1_Write(10);
    Delay_ms(1000);
  }
}
