/*
 * Project_name:
     Port Expander port on LCD
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Initial release;
    - 20101029(RR);
 * Description:
     This is code that shows on LCD what are input values on Port Expander Module Ports.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf

     Dev.Board:       Easy8051v6
                      http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/

     Oscillator:      External Clock 8.0000 MHz

     Ext. Modules:    Port Expander Board
                      http://www.mikroe.com/eng/products/view/142/port-expander-board/

     SW:              mikroC PRO for 8051 v2.20
                      http://www.mikroe.com/en/compilers/mikroc/8051/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
                                                 Selector on 0 (all three jumpers A0, A1 and A2)
  - Turn On LCD Backlight Switch (SW7.6)
*/


// Port Expander module connections
sbit  SPExpanderRST at P1_0_bit;
sbit  SPExpanderCS  at P1_1_bit;
// End Port Expander module connections

// LCD module connections
sbit LCD_RS at P2_0_bit;
sbit LCD_EN at P2_1_bit;

sbit LCD_D4 at P2_2_bit;
sbit LCD_D5 at P2_3_bit;
sbit LCD_D6 at P2_4_bit;
sbit LCD_D7 at P2_5_bit;
// End LCD module connections

char byteread;

void Lcd_Byte2Bin_Out(char row, char col, char data1) {
char mask;

  mask = 0b10000000;
  if (data1 & mask)
    Lcd_Chr(row,col,49);
  else
    Lcd_Chr(row,col,48);
  mask >>= 1;

  while (mask > 0 ) {
    if (data1 & mask)
      Lcd_Chr_CP(49);
    else
      Lcd_Chr_CP(48);
    mask >>= 1;
  }
}

void main(){

  Lcd_Init();                           // change to portD for EasyPIC4
  Lcd_Cmd(_LCD_CLEAR);
  Lcd_Cmd(_LCD_CURSOR_OFF);
  LCD_Out(1,1,"PORTA :");
  LCD_Out(2,1,"PORTB :");

  Spi1_Init();
  Expander_Init(0);                     // initialize port expander

  Expander_Set_DirectionPortA(0, 0xFF); // set expander's portA to be input
  Expander_Set_PullUpsPortA(0, 0xFF);   // set expander's portA pull-up resistors

  Expander_Set_DirectionPortB(0, 0xFF); // set expander's portB to be input
  Expander_Set_PullUpsPortB(0, 0xFF);   // set expander's portB pull-up resistors

  while(1) {
    byteread = Expander_Read_PortA(0);
    Lcd_Byte2Bin_Out(1,9,byteread);

    byteread = Expander_Read_PortB(0);
    Lcd_Byte2Bin_Out(2,9,byteread);
  }
}
