/*
 * Project_name:
     Port Expander ports as Output
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Initial release;
    - 20101029(RR);
 * Description:
     This is code that sets Port Expander ports as Output.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf

     Dev.Board:       Easy8051v6
                      http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/

     Oscillator:      External Clock 8.0000 MHz

     Ext. Modules:    Port Expander Board
                      http://www.mikroe.com/eng/products/view/142/port-expander-board/

     SW:              mikroC PRO for 8051 v2.20
                      http://www.mikroe.com/en/compilers/mikroc/8051/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
                                                    Selector on 0 (all three jumpers A0, A1 and A2)
*/


// Port Expander module connections
sbit  SPExpanderRST at P1_0_bit;
sbit  SPExpanderCS  at P1_1_bit;
// End Port Expander module connections

unsigned int i;

void main(){
  Spi1_Init();
  Expander_Init(0);                     // initialize port expander

  Expander_Set_DirectionPortA(0, 0);    // set expander's portA to be output
  Expander_Set_DirectionPortB(0, 0);    // set expander's portB to be output


  for (i=0 ; i<256 ; i++) {
    Expander_Write_PortA(0,i);          // write byte on expander's portA
    Expander_Write_PortB(0,255-i);      // write byte on expander's portB
    Delay_ms(1000);
  }
}
