/*
 * Project_name:
     Port Expander port on LED
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Second release;
    - 20101026(RR);
 * Description:
     This is code that shows on LEDs what are input values on Port Expander Module Ports.
 * Test configuration:
     MCU:             ac:ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf

     Dev.Board:       ac:EasyAVR6
                      http://www.mikroe.com/eng/products/view/321/easyavr6-development-system/

     Oscillator:      External Clock 08.0000 MHz

     Ext. Modules:    ac:Port_Expander_Board
                      http://www.mikroe.com/eng/products/view/142/port-expander-board/

     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
						 Selector on 0 (all three jumpers A0, A1 and A2)
  - Turn On LED Switches for PortA and PortC (SW8.1 and SW8.3)
*/


// Port Expander module connections
sbit  SPExpanderRST at PORTB0_bit;
sbit  SPExpanderCS  at PORTB1_bit;
sbit  SPExpanderRST_Direction at DDB0_bit;
sbit  SPExpanderCS_Direction  at DDB1_bit;
// End Port Expander module connections

void main(){

  PORTA = 0;
  PORTC = 0;

  Spi1_Init();
  Expander_Init(0);                           // initialize port expander

  Expander_Set_DirectionPortA(0, 0xFF);       // set expander's portA to be input
  Expander_Set_PullUpsPortA(0, 0xFF);         // set expander's portA pull-up resistors

  Expander_Set_DirectionPortB(0, 0xFF);       // set expander's portB to be input
  Expander_Set_PullUpsPortB(0, 0xFF);         // set expander's portB pull-up resistors

  while(1) {
    PORTA = Expander_Read_PortA(0);           // display expander's portA on portB leds
    PORTC = Expander_Read_PortB(0);           // display expander's portB on portD leds
    Delay_100ms();
  }
}