/*
 * Project_name:
     Port Expander port on LED
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Initial release;
    - 20101026(RR);
 * Description:
     This is code that shows on LEDs what are input values on Port Expander Module Ports.
 * Test configuration:
     mcu:                 ac:PIC16F887
                          http://ww1.microchip.com/downloads/en/DeviceDoc/41291F.pdf
         
     Dev.Board:           ac:EasyPIC6
                          http://www.mikroe.com/en/tools/easypic6/

     Oscillator:          Internal Clock, 8.0000 MHz

     Ext. Modules:        ac:Port_Expander_Board
                          http://www.mikroe.com/eng/products/view/142/port-expander-board/
                                                  
     sw:                  mikroC PRO for PIC v4.15
                          http://www.mikroe.com/en/compilers/mikropascal/pro/pic/
         
 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
                                                 Selector on 0 (all three jumpers A0, A1 and A2)
  - Turn On LED Switches for PortB and PortD (SW9.2 and SW9.4)
*/


// Port Expander module connections
sbit  SPExpanderRST at RC0_bit;
sbit  SPExpanderCS  at RC1_bit;
sbit  SPExpanderRST_Direction at TRISC0_bit;
sbit  SPExpanderCS_Direction  at TRISC1_bit;
// End Port Expander module connections

void main(){
  ANSEL  = 0;                                 // Configure AN pins as digital I/O
  ANSELH = 0;

  TRISB = 0;
  TRISD = 0;
  
  PORTB = 0;
  PORTD = 0;

  Spi1_Init();
  Expander_Init(0);                           // initialize port expander

  Expander_Set_DirectionPortA(0, 0xFF);       // set expander's portA to be input
  Expander_Set_PullUpsPortA(0, 0xFF);         // set expander's portA pull-up resistors

  Expander_Set_DirectionPortB(0, 0xFF);       // set expander's portB to be input
  Expander_Set_PullUpsPortB(0, 0xFF);         // set expander's portB pull-up resistors

  while(1) {
    PORTB = Expander_Read_PortA(0);           // display expander's portA on portB leds
    PORTD = Expander_Read_PortB(0);           // display expander's portB on portD leds
    Delay_100ms();
  }
}