/*
 * Project_name:
     Port Expander ports as Output
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Initial release;
    - 20101029(RR);
 * Description:
     This is code that sets Port Expander ports as Output.
 * Test configuration:
     mcu:                 ac:PIC16F887
                          http://ww1.microchip.com/downloads/en/DeviceDoc/41291F.pdf

     Dev.Board:           ac:EasyPIC6
                          http://www.mikroe.com/en/tools/easypic6/

     Oscillator:          Internal Clock, 8.0000 MHz

     Ext. Modules:        ac:Port_Expander_Board
                          http://www.mikroe.com/eng/products/view/142/port-expander-board/

     sw:                  mikroC PRO for PIC v4.15
                          http://www.mikroe.com/en/compilers/mikroc/pro/pic/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
                                                    Selector on 0 (all three jumpers A0, A1 and A2)
*/


// Port Expander module connections
sbit  SPExpanderRST at RC0_bit;
sbit  SPExpanderCS  at RC1_bit;
sbit  SPExpanderRST_Direction at TRISC0_bit;
sbit  SPExpanderCS_Direction  at TRISC1_bit;
// End Port Expander module connections

unsigned int i;

void main(){
  Spi1_Init();
  Expander_Init(0);                     // initialize port expander

  Expander_Set_DirectionPortA(0, 0);    // set expander's portA to be output
  Expander_Set_DirectionPortB(0, 0);    // set expander's portB to be output


  for (i=0 ; i<256 ; i++) {
    Expander_Write_PortA(0,i);          // write byte on expander's portA
    Expander_Write_PortB(0,255-i);      // write byte on expander's portB
    Delay_ms(1000);
  }
}