/*
 * Project_name:
     Port Expander port on LED
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Second release;
    - 20101026(RR);
 * Description:
     This is code that shows on LEDs what are input values on Port Expander Module Ports.
 * Test configuration:
    mcu:                 ac:dsPIC30F4013
			 http://ww1.microchip.com/downloads/en/devicedoc/70138c.pdf

    Dev.Board:           ac:EasydsPIC6
			 http://www.mikroe.com/eng/products/view/434/easydspic6-development-system/

    Oscillator:          XT, 10.0000 MHz without PLL

    Ext. Modules:        ac:Port_Expander_Board
			 http://www.mikroe.com/eng/products/view/142/port-expander-board/

    sw:                  mikroC PRO for dsPIC v4.10
			 http://www.mikroe.com/en/compilers/mikroc/pro/dspic/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
						 Selector on 0 (all three jumpers A0, A1 and A2)
  - Turn On LED Switches for PortB and PortD (SW12.1 and SW12.2)
*/


// Port Expander module connections
sbit  SPExpanderRST at RF0_bit;
sbit  SPExpanderCS  at RF1_bit;
sbit  SPExpanderRST_Direction at TRISF0_bit;
sbit  SPExpanderCS_Direction  at TRISF1_bit;
// End Port Expander module connections

char Temp;

void main(){

  ADPCFG = 0xFFFF;                            // initialize AN pins as digital

  TRISB = 0x0000;
  TRISD = 0x0000;
  
  PORTB = 0x0000;
  PORTD = 0x0000;

  Spi1_Init();
  Expander_Init(0);                           // initialize port expander

  Expander_Set_DirectionPortA(0, 0xFF);       // set expander's portA to be input
  Expander_Set_PullUpsPortA(0, 0xFF);         // set expander's portA pull-up resistors

  Expander_Set_DirectionPortB(0, 0xFF);       // set expander's portB to be input
  Expander_Set_PullUpsPortB(0, 0xFF);         // set expander's portB pull-up resistors

  while(1) {
    PORTB = Expander_Read_PortA(0);           // display expander's portA on portB leds
    Temp = Expander_Read_PortB(0);            // display expander's portB on portD leds
    PortB.B8 = Temp.B0;
    PortB.B9 = Temp.B1;
    PortB.B10 = Temp.B2;
    PortB.B11 = Temp.B3;
    PortD.B0 = Temp.B4;
    PortD.B1 = Temp.B5;
    PortD.B2 = Temp.B6;
    PortD.B3 = Temp.B7;
    Delay_100ms();
  }
}