/*
 * Project_name:
     Port Expander port on RS232
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Initial release;
    - 20101029(RR);
 * Description:
     This is code that shows over RS232 what are input values on Port Expander Module Ports.
 * Test configuration:
    mcu:                 ac:dsPIC30F4013
                         http://ww1.microchip.com/downloads/en/devicedoc/70138c.pdf

    Dev.Board:           ac:EasydsPIC6
			 http://www.mikroe.com/eng/products/view/434/easydspic6-development-system/

    Oscillator:          XT, 10.0000 MHz without PLL

    Ext. Modules:        ac:Port_Expander_Board
			 http://www.mikroe.com/eng/products/view/142/port-expander-board/

    sw:                  mikroC PRO for dsPIC v4.10
			 http://www.mikroe.com/en/compilers/mikroc/pro/dspic/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
						 Selector on 0 (all three jumpers A0, A1 and A2)
  - Turn On RS232 Switches (SW7.2 and SW7.6)
*/


// Port Expander module connections
sbit  SPExpanderRST at RF0_bit;
sbit  SPExpanderCS  at RF1_bit;
sbit  SPExpanderRST_Direction at TRISF0_bit;
sbit  SPExpanderCS_Direction  at TRISF1_bit;
// End Port Expander module connections

char byteread;

void Byte2Bin_UART(char data1) {
  char mask;

  mask = 0b10000000;
  while (mask > 0 ) {
    if (data1 & mask)
      UART1_Write(49);
    else
      UART1_Write(48);
    mask >>= 1;
  }
  UART1_Write(13);
  UART1_Write(10);
}

void main(){
  UART1_Init(9600);

  Spi1_Init();
  Expander_Init(0);                         // initialize port expander

  Expander_Set_DirectionPortA(0, 0xFF);     // set expander's portA to be input
  Expander_Set_PullUpsPortA(0, 0xFF);       // set expander's portA pull-up resistors

  Expander_Set_DirectionPortB(0, 0xFF);     // set expander's portB to be input
  Expander_Set_PullUpsPortB(0, 0xFF);       // set expander's portB pull-up resistors

  while(1) {                                // unending loop
    byteread = Expander_Read_PortA(0);      // it reads Expander Port A and B
    UART1_Write('A');                       // and sends data over RS232
    UART1_Write(':');
    Byte2Bin_UART(byteread);

    byteread = Expander_Read_PortB(0);
    UART1_Write('B');
    UART1_Write(':');
    Byte2Bin_UART(byteread);

    UART1_Write(13);
    UART1_Write(10);
    Delay_ms(1000);
  }
}