/*
 * Project_name:
     Port Expander ports as Output
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101029:
    - Initial release;
    - 20101029(RR);
 * Description:
     This is code that sets Port Expander ports as Output.
 * Test configuration:
    mcu:                 ac:dsPIC30F4013
                         http://ww1.microchip.com/downloads/en/devicedoc/70138c.pdf

    Dev.Board:           ac:EasydsPIC6
                         http://www.mikroe.com/eng/products/view/434/easydspic6-development-system/

    Oscillator:          XT, 10.0000 MHz without PLL

    Ext. Modules:        ac:Port_Expander_Board
                         http://www.mikroe.com/eng/products/view/142/port-expander-board/

    sw:                  mikroC PRO for dsPIC v4.10
                         http://www.mikroe.com/en/compilers/mikroc/pro/dspic/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Port Expander Board must be connected on PortC and Hardware Address
                                                    Selector on 0 (all three jumpers A0, A1 and A2)
*/


// Port Expander module connections
sbit  SPExpanderRST at RF0_bit;
sbit  SPExpanderCS  at RF1_bit;
sbit  SPExpanderRST_Direction at TRISF0_bit;
sbit  SPExpanderCS_Direction  at TRISF1_bit;
// End Port Expander module connections

unsigned int i;

void main(){
  Spi1_Init();
  Expander_Init(0);                     // initialize port expander

  Expander_Set_DirectionPortA(0, 0);    // set expander's portA to be output
  Expander_Set_DirectionPortB(0, 0);    // set expander's portB to be output


  for (i=0 ; i<256 ; i++) {
    Expander_Write_PortA(0,i);          // write byte on expander's portA
    Expander_Write_PortB(0,255-i);      // write byte on expander's portB
    Delay_ms(1000);
  }
}